diff -pruN 0.7.1-9/debian/changelog 0.7.1-10/debian/changelog
--- 0.7.1-9/debian/changelog	2020-11-16 10:16:20.000000000 +0000
+++ 0.7.1-10/debian/changelog	2024-08-05 20:48:54.000000000 +0000
@@ -1,3 +1,12 @@
+maq (0.7.1-10) unstable; urgency=medium
+
+  * gcc-14.patch: new: fix improper uses of gzFile pointers. (Closes: #1075253)
+  * d/*lintian-overrides: update mismatched overrides.
+  * d/control: declare compliance to standards version 4.7.0.
+  * d/control: add myself to uploaders.
+
+ -- Étienne Mollier <emollier@debian.org>  Mon, 05 Aug 2024 22:48:54 +0200
+
 maq (0.7.1-9) unstable; urgency=medium
 
   * Standards-Version: 4.5.0 (routine-update)
diff -pruN 0.7.1-9/debian/control 0.7.1-10/debian/control
--- 0.7.1-9/debian/control	2020-11-16 10:16:20.000000000 +0000
+++ 0.7.1-10/debian/control	2024-08-05 20:48:54.000000000 +0000
@@ -1,12 +1,13 @@
 Source: maq
 Maintainer: Debian Med Packaging Team <debian-med-packaging@lists.alioth.debian.org>
 Uploaders: Andreas Tille <tille@debian.org>,
-           Charles Plessy <plessy@debian.org>
+           Charles Plessy <plessy@debian.org>,
+           Étienne Mollier <emollier@debian.org>
 Section: science
 Priority: optional
 Build-Depends: debhelper-compat (= 13),
                zlib1g-dev
-Standards-Version: 4.5.0
+Standards-Version: 4.7.0
 Vcs-Browser: https://salsa.debian.org/med-team/maq
 Vcs-Git: https://salsa.debian.org/med-team/maq.git
 Homepage: http://maq.sourceforge.net/
diff -pruN 0.7.1-9/debian/maq.lintian-overrides 0.7.1-10/debian/maq.lintian-overrides
--- 0.7.1-9/debian/maq.lintian-overrides	2020-11-16 10:16:20.000000000 +0000
+++ 0.7.1-10/debian/maq.lintian-overrides	2024-08-05 20:48:54.000000000 +0000
@@ -1,4 +1,3 @@
 # Maq ships `maq' and `maq.pl', it is therefore not possible to rename `maq.pl'.
-maq: script-with-language-extension usr/bin/maq.pl
-# see https://lists.debian.org/debian-med/2018/06/msg00043.html
-maq: script-with-language-extension usr/bin/*.*
+# also see https://lists.debian.org/debian-med/2018/06/msg00043.html
+maq: script-with-language-extension [usr/bin/*.pl]
diff -pruN 0.7.1-9/debian/patches/gcc-14.patch 0.7.1-10/debian/patches/gcc-14.patch
--- 0.7.1-9/debian/patches/gcc-14.patch	1970-01-01 00:00:00.000000000 +0000
+++ 0.7.1-10/debian/patches/gcc-14.patch	2024-08-05 20:48:54.000000000 +0000
@@ -0,0 +1,45 @@
+Description: fix improper variable declaration as a pointer.
+ On two occasions, a gzFile is declared as a pointer, except the type
+ mismatches with the expected type by the gz API, resulting in errors
+ like:
+ .
+ 	fastq2bfq.c:30:12: error: assignment to ‘struct gzFile_s **’ from incompatible pointer type ‘gzFile’ {aka ‘struct gzFile_s *’} [-Wincompatible-pointer-types]
+ 	   30 |         fp = gzopen(str, "w");
+ 	      |            ^
+ 	fastq2bfq.c:36:28: error: assignment to ‘struct gzFile_s **’ from incompatible pointer type ‘gzFile’ {aka ‘struct gzFile_s *’} [-Wincompatible-pointer-types]
+ 	   36 |                         fp = gzopen(str, "w");
+ 	      |                            ^
+ 	fastq2bfq.c:47:25: error: passing argument 1 of ‘gzwrite’ from incompatible pointer type [-Wincompatible-pointer-types]
+ 	   47 |                 gzwrite(fp, &i, sizeof(int));
+ 	      |                         ^~
+ 	      |                         |
+ 	      |                         struct gzFile_s **
+
+Author: Étienne Mollier <emollier@debian.org>
+Bug-Debian: https://bugs.debian.org/cgi-bin/bugreport.cgi?bug=1075253
+Forwarded: no
+Last-Update: 2024-08-05
+---
+This patch header follows DEP-3: http://dep.debian.net/deps/dep3/
+--- maq.orig/fastq2bfq.c
++++ maq/fastq2bfq.c
+@@ -15,7 +15,7 @@
+ 	char name[256], str[1024];
+ 	int l, is_new = 0, l_prefix = 0;
+ 	bit64_t n;
+-	gzFile *fp = 0;
++	gzFile fp = 0;
+ 	INIT_SEQ(seq); INIT_SEQ(qual);
+ 	seq_set_block_size(256);
+ 	n = 0;
+--- maq.orig/simulate.c
++++ maq/simulate.c
+@@ -74,7 +74,7 @@
+ {
+ 	fqc_t *fqc;
+ 	FILE *fp;
+-	gzFile *fpout;
++	gzFile fpout;
+ 	if (argc < 3) {
+ 		fprintf(stderr, "Usage: maq simutrain <simupars.dat> <known_reads.fastq>\n");
+ 		return 1;
diff -pruN 0.7.1-9/debian/patches/series 0.7.1-10/debian/patches/series
--- 0.7.1-9/debian/patches/series	2020-11-16 10:16:20.000000000 +0000
+++ 0.7.1-10/debian/patches/series	2024-08-05 20:48:54.000000000 +0000
@@ -1,3 +1,4 @@
 10_prevent_-64_option.patch
 gcc-4.7.patch
 mayhem.patch
+gcc-14.patch
